# Project KINETIC
[![forthebadge](https://forthebadge.com/images/badges/contains-technical-debt.svg)](https://forthebadge.com) [![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)](https://forthebadge.com)

Control modular and configurable robotic agents over the network. 

## Documentation
To see documentation regarding installation and usage, please visit [https://dreamerslegacy.xyz/projects/kinetic/docs/index.html](https://dreamerslegacy.xyz/projects/kinetic/docs/index.html).

## Releases & Dist.
With the released wheel file, after downloading:
```commandline
pip3 install /path/to/wheel/file/here/project_kinetic-1.0-py3-none-any.whl
```
...Or available on PyPI through:
```commandline
pip3 install project-kinetic
```
Please see documentation for more information.
